-- Project: Sprites
-- SDK: Corona - 09/12/11
-- Author: Andrew Burch
-- Date: 03/09/2012
-- Site: http://www.newhighscore.net
-- Contact: andrew.burch@newhighscore.net
-- Note: Demo to show construction of animation sets

local spriteconfig = require('config.spriteconfig')
local spritefactory = require('systems.spritefactory')
local gamesprite = require('objects.gamesprite')

-- hide status bar
display.setStatusBar(display.HiddenStatusBar)

-- setup background
local contentWidth = display.contentWidth
local contentHeight = display.contentHeight

local displayGroup = display.newGroup()
local background = display.newRect(displayGroup, 0, 0, contentWidth, contentHeight)
background:setFillColor(0, 0, 0)

-- initialise the sprite factory system
local spriteFactory = spritefactory.new()
spriteFactory:initialiseFromConfig(spriteconfig.spriteLibrary)

-- create the game object
local gameobject = gamesprite.new()
gameobject:initialise {
				x = contentWidth * 0.5,
				y = contentWidth * 0.5,
				spriteId = 'robot',
				spriteSetId = 'default',
				spriteFactory = spriteFactory,
				movementSpeed = 0.4,
			}
			

-- create touch event to move sprite around screen
background:addEventListener('touch', function(event)
								local phase = event.phase
								if phase ~= 'began' then
									return
								end
								
								gameobject:moveToTarget(event.x, event.y)
								
								return true
							end)

local lastUpdateTime = 0

-- register main update listener
Runtime:addEventListener('enterFrame', function(event)
											local time = event.time
											local dt = (time - lastUpdateTime) / 1000

											gameobject:update(dt, time)

											lastUpdateTime = time
										end)
										